"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = Media;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _react = _interopRequireDefault(require("react"));

var _Image = _interopRequireDefault(require("../Image"));

var _reactImageMagnify = _interopRequireDefault(require("react-image-magnify"));

/**
 * An element that determines the proper tag to use for a media node within a
 * [`Carousel`](/apiReference/carousel%f2Carousel).
 */
function Media(_ref) {
  var magnifyProps = _ref.magnifyProps,
      imageProps = _ref.imageProps,
      src = _ref.src,
      alt = _ref.alt,
      magnify = _ref.magnify,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'image' : _ref$type;

  if (type === 'video') {
    return _react["default"].createElement("video", {
      src: src,
      alt: alt
    });
  } else if (magnify) {
    return _react["default"].createElement(_reactImageMagnify["default"], (0, _extends2["default"])({
      enlargedImagePosition: "over"
    }, magnifyProps, {
      smallImage: {
        src: src,
        alt: alt,
        isFluidWidth: true
      },
      largeImage: magnify
    }));
  } else {
    return _react["default"].createElement(_Image["default"], (0, _extends2["default"])({
      key: src,
      src: src,
      alt: alt,
      fill: true
    }, imageProps));
  }
}

Media.propTypes = {
  /**
   * The type of media to display.
   */
  type: _propTypes["default"].oneOf(['image', 'video']),

  /**
   * Props passed to the [`ReactImageMagnify`](https://github.com/ethanselzer/react-image-magnify#usage)
   * element for an `'image'` type when [`magnify`](#prop-magnify) is `true`.
   */
  magnifyProps: _propTypes["default"].object,

  /**
   * Other props to pass to the [`Image`](/apiReference/Image) for an `'image'` type.
   */
  imageProps: _propTypes["default"].object,

  /**
   * Used as the `alt` tag for an `'image'` type.
   */
  alt: _propTypes["default"].string,

  /**
   * Used as the `src` tag for an `'image'` type.
   */
  src: _propTypes["default"].string,

  /**
   * If `true`, the media is able to be magnified and should use `ReactImageMagnify`.
   */
  magnify: _propTypes["default"].bool
};
//# sourceMappingURL=Media.js.map