"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = fulfillAPIRequest;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

/**
 * Creates an API response that contains app level data only when `?_includeAppData=1` is present in
 * the query string. Otherwise, the `appData` promise provided will not be resolved.
 *
 * @param {Request} req The request being served
 * @param {Object} options
 * @param {Function} options.appData An async function that returns a data for shared component in
 * the app such as menu, nav, and footer
 * @param {Function} options.pageData An async function that return data for the page component
 * @return {Object} the result of `appData` and `pageData` merged into a single object.
 */
function fulfillAPIRequest(_x) {
  return _fulfillAPIRequest.apply(this, arguments);
}

function _fulfillAPIRequest() {
  _fulfillAPIRequest = (0, _asyncToGenerator2["default"])(
  /*#__PURE__*/
  _regenerator["default"].mark(function _callee(req) {
    var _ref,
        appData,
        pageData,
        promises,
        results,
        data,
        _iteratorNormalCompletion,
        _didIteratorError,
        _iteratorError,
        _iterator,
        _step,
        result,
        _args = arguments;

    return _regenerator["default"].wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _ref = _args.length > 1 && _args[1] !== undefined ? _args[1] : {}, appData = _ref.appData, pageData = _ref.pageData;
            promises = [pageData(req).then(function (pageData) {
              return {
                pageData: pageData
              };
            })];

            if (req.query._includeAppData === '1') {
              promises.push(appData(req).then(function (appData) {
                return {
                  appData: appData
                };
              }));
            }

            _context.next = 5;
            return Promise.all(promises);

          case 5:
            results = _context.sent;
            data = {};
            _iteratorNormalCompletion = true;
            _didIteratorError = false;
            _iteratorError = undefined;
            _context.prev = 10;

            for (_iterator = results[Symbol.iterator](); !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
              result = _step.value;
              Object.assign(data, result);
            }

            _context.next = 18;
            break;

          case 14:
            _context.prev = 14;
            _context.t0 = _context["catch"](10);
            _didIteratorError = true;
            _iteratorError = _context.t0;

          case 18:
            _context.prev = 18;
            _context.prev = 19;

            if (!_iteratorNormalCompletion && _iterator["return"] != null) {
              _iterator["return"]();
            }

          case 21:
            _context.prev = 21;

            if (!_didIteratorError) {
              _context.next = 24;
              break;
            }

            throw _iteratorError;

          case 24:
            return _context.finish(21);

          case 25:
            return _context.finish(18);

          case 26:
            return _context.abrupt("return", data);

          case 27:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, null, [[10, 14, 18, 26], [19,, 21, 25]]);
  }));
  return _fulfillAPIRequest.apply(this, arguments);
}
//# sourceMappingURL=fulfillAPIRequest.js.map