"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = withCaching;

/**
 * Creates a cancelable event handler that will run unless the provided
 * handler calls `e.preventDefault()`.
 *
 * @param {Function} handler The original event handle supplied to the component
 * @param {Function} defaultHandler A handler to run unless `e.preventDefault()` was called.
 * @return {Function}
 */
function withCaching(handler, _ref) {
  var browser = _ref.browser,
      edge = _ref.edge;
  return function (req, res) {
    if (browser.maxAgeSeconds) {
      res.setHeader('x-rsf-cache-control', "max-age: ".concat(browser.maxAgeSeconds));
    }

    return handler(req, res);
  };
}
//# sourceMappingURL=withCaching.js.map